@@ -1,4 +1,4 @@
-#include "zeek-config.h"
+#include "zeek/zeek-config.h"
 
 #include "zeek/RuleCondition.h"
 #include "zeek/RuleMatcher.h"
