@@ -1,14 +1,15 @@
 // See the file "COPYING" in the main distribution directory for copyright.
 
-#include "KRB_TCP.h"
-#include "analyzer/protocol/tcp/TCP_Reassembler.h"
-#include "types.bif.h"
-#include "events.bif.h"
+#include "zeek/analyzer/protocol/krb/KRB_TCP.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Reassembler.h"
 
-using namespace analyzer::krb_tcp;
+#include "analyzer/protocol/krb/types.bif.h"
+#include "analyzer/protocol/krb/events.bif.h"
+
+namespace zeek::analyzer::krb_tcp {
 
 KRB_Analyzer::KRB_Analyzer(Connection* conn)
-	: tcp::TCP_ApplicationAnalyzer("KRB_TCP", conn)
+	: analyzer::tcp::TCP_ApplicationAnalyzer("KRB_TCP", conn)
 	{
 	interp = new binpac::KRB_TCP::KRB_Conn(this);
 	had_gap = false;
@@ -21,7 +22,7 @@ KRB_Analyzer::~KRB_Analyzer()
 
 void KRB_Analyzer::Done()
 	{
-	tcp::TCP_ApplicationAnalyzer::Done();
+	analyzer::tcp::TCP_ApplicationAnalyzer::Done();
 
 	interp->FlowEOF(true);
 	interp->FlowEOF(false);
@@ -29,13 +30,13 @@ void KRB_Analyzer::Done()
 
 void KRB_Analyzer::EndpointEOF(bool is_orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::EndpointEOF(is_orig);
 	interp->FlowEOF(is_orig);
 	}
 
 void KRB_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::DeliverStream(len, data, orig);
 
 	assert(TCP());
 	if ( TCP()->IsPartial() )
@@ -53,13 +54,15 @@ void KRB_Analyzer::DeliverStream(int len, const u_char* data, bool orig)
 		}
 	catch ( const binpac::Exception& e )
 		{
-		ProtocolViolation(fmt("Binpac exception: %s", e.c_msg()));
+		ProtocolViolation(util::fmt("Binpac exception: %s", e.c_msg()));
 		}
 	}
 
-void KRB_Analyzer::Undelivered(uint64 seq, int len, bool orig)
+void KRB_Analyzer::Undelivered(uint64_t seq, int len, bool orig)
 	{
-	tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
+	analyzer::tcp::TCP_ApplicationAnalyzer::Undelivered(seq, len, orig);
 	had_gap = true;
 	interp->NewGap(orig, len);
 	}
+
+} // namespace zeek::analyzer::krb_tcp
